rudie
rudie has a Kalman Filter implementation that will work on embedded platforms for robotics applications.
Using rudie
You will need the last stable build of the rust compiler and the official package manager: cargo.
Simply add the following to your Cargo.toml file:
[dependencies]
rudie = "0.1"Features
rudie is meant to collect together Kalman filter implementations that may be used on embedded
devices for robotics applications since it is designed to run on #![no_std] targets.
Those features include:
- An implementation of the OpenCV Kalman filter that will run on
#![no_std]targets
Re-exports
pub extern crate generic_array;pub extern crate nalgebra as na;pub extern crate typenum;
Structs
- Kalman
Filter - A Rust implementation of the OpenCV Kalman Filter